/*
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

#pragma once

#include <cstdint>

namespace apache {
namespace thrift {
namespace type {
enum class UniversalHashAlgorithm {
  Sha2_256 = 2,
};

constexpr int8_t const kMinHashBytes = 8;
constexpr int8_t const kDefaultHashBytes = 16;
} // namespace type
} // namespace thrift
} // namespace apache
